/*
 * Copyright (c) 1991 Regents of the University of California.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that the above copyright notice and this paragraph are
 * duplicated in all such forms and that any documentation,
 * advertising materials, and other materials related to such
 * distribution and use acknowledge that the software was developed
 * by the University of California, Lawrence Berkeley Laboratory,
 * Berkeley, CA.  The name of the University may not be used to
 * endorse or promote products derived from this software without
 * specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * (modified for VCR by Wieland Holfelder)
 *
 */

/* $Id: vat.h,v 1.2 1996/08/02 15:24:35 whd Exp $ (ICSI) */


#ifndef _VAT_PACKET_H
#define _VAT_PACKET_H

#include "it_depends.h"

/*
 * vat packet header (0 is MSB):
 *
 *  0                   1                   2                   3   
 *  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 
 * +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 * | V |           |T|   |         |                               |
 * | e |    NSID   |S| 0 |  Audio  |        Conference ID          |
 * | r |           | |   | Format  |                               |
 * +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 * |                                                               |
 * |                 Time Stamp (in audio samples)                 |
 * |                                                               |
 * +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 *
 *  protocol version (2 bits)
 *  no. of speaker id's (6 bits) [= 0 if src address should be used as id]
 *  flags (3 bits)
 *  audio format (5 bits)
 *  conference identifier (16 bits)
 *  timestamp [in audio samples] (32 bits)
 *  <0 to 63 4-byte speaker id's>
 *  <audio data>
 */
typedef struct {
	u_int16_t flags;
#define		VATHF_VER	0xC000
#define		VATHF_NSID	0x3F00
#define		VATHF_NEWTS	0x0080	/* set if start of new talkspurt */
#define		VATHF_FMTMASK	0x001F	/* audio format bits */
	u_int16_t confid;
	u_int32_t ts;
} vat_hdr_t;

/*
 * Audio formats.
 *   Numbers for 'standard' encodings are assigned 0 upwards.
 *   Numbers for 'experimental' or non-standard encodings are
 *   assigned from 30 downwards.  31 is reserved.  The intent
 *   is that the lower numbers will be globally known and widely
 *   implemented & others will be used only between mutually
 *   consenting programs.
 */
#define AUDF_MULAW8	0	/* 64 kb/s 8KHz mu-law encoded PCM */
#define AUDF_CELP	1	/* 4.8 kb/s FED-STD-1016 CELP */
#define AUDF_G721	2	/* 32 kb/s CCITT ADPCM */
#define AUDF_GSM        3       /* 13 kb/s GSM */
#define AUDF_G723       4       /* 24 kb/s CCITT ADPCM */
#define AUDF_LPC4       28      /* 4.8 kb/s LPC, 4 frames */
#define AUDF_LPC1	29	/* 4.8 kb/s LPC, 1 frame */
#define AUDF_IDVI	30	/* 32 kb/s Intel DVI ADPCM */
#define AUDF_UNDEF      31      /* undefined */

/*
 * Structure of a vat control message (sent to the 'session' port).
 * All msgs have the same header:
 *  protocol version (2 bits)
 *  flags / misc (6 bits)
 *  msg type (8 bits)
 *  conference id
 *
 * An 'ID' message has a null-terminated ascii string giving the
 * site id string immediately following the header.
 *
 * A 'DONE' message has no other information.
 *
 * The structure of an IDLIST is described below.
 */
struct CtrlMsgHdr {
	u_int16_t flags;
#define		CTRHF_VER	0xC000
#define		CTRHF_FLAGS	0x3F00
#define		CTRHF_MSGTYPE	0x00FF
	u_int16_t confid;
};

#define CTRL_TYPE_ID 1
#define CTRL_TYPE_DONE 2
#define CTRL_TYPE_IDLIST 3

/*
 * An IDLIST message contains:
 *  control msg hdr
 *  number of site id's in this msg (8 bits)
 *  audio flags (3 bits)
 *  audio format (5 bits)
 *  audio block size (16 bits)
 *  <site id entries>
 * Each site id entry consists of a 4 byte site id followed by a
 * null terminated ascii id string.  The string is padded with
 * nulls to the next 4 byte boundary.
 */
struct IDMsgHdr {
	struct CtrlMsgHdr h;
	u_int16_t  flags;
#define		IDMHF_NBOS	0xFF00
#define		IDMHF_AFLAGS	0x00E0
#define		IDMHF_AFORMAT	0x001F
	u_int16_t blksize;
};

#endif
